# `ide50`

[![Build Status](https://travis-ci.com/cs50/ide50.svg?branch=master)](https://travis-ci.org/cs50/ide50)

This is `ide50`, a command-line script that facilitates using [CS50 IDE](https://cs50.readthedocs.io/ide/offline/).
